﻿using Syncfusion.SfDataGrid.XForms;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using Xamarin.Forms;

namespace XamarinForms
{
    public class App : Application
    {
        SfDataGrid dataGrid;
        ViewModel viewModel;
        public App()
        {
            dataGrid = new SfDataGrid();
            viewModel = new ViewModel();
            dataGrid.AutoGenerateColumns = false;
            dataGrid.ItemsSource = viewModel.OrdersInfo;
            dataGrid.ColumnSizer = ColumnSizer.Star;

            dataGrid.CellRenderers.Remove("TextView");
            dataGrid.CellRenderers.Add("TextView", new GridCellTextViewRendererExt());

            GridTextColumn orderIDColumn = new GridTextColumn();
            orderIDColumn.MappingName = "OrderID";
            Style style = new Style(typeof(GridCell));
            style.Setters.Add(new Setter() { Property = GridCell.ForegroundProperty, Value = new Binding("OrderID", BindingMode.TwoWay, new StyleConverter()) });
            orderIDColumn.CellStyle = style;
            orderIDColumn.LoadUIView = true;
            dataGrid.Columns.Add(orderIDColumn);

          
            GridTextColumn EmpIDColumn = new GridTextColumn();
            EmpIDColumn.MappingName = "EmployeeID";
            EmpIDColumn.LoadUIView = true;
            dataGrid.Columns.Add(EmpIDColumn);

            GridTextColumn CustomerIDColumn = new GridTextColumn();
            CustomerIDColumn.MappingName = "CustomerID";
            CustomerIDColumn.LoadUIView = true;
            dataGrid.Columns.Add(CustomerIDColumn);

            GridTextColumn FirstNameColumn = new GridTextColumn();
            FirstNameColumn.MappingName = "FirstName";
            FirstNameColumn.LoadUIView = true;
            dataGrid.Columns.Add(FirstNameColumn);

            GridTextColumn GenderColumn = new GridTextColumn();
            GenderColumn.MappingName = "Gender";
            GenderColumn.LoadUIView = true;
            dataGrid.Columns.Add(GenderColumn);
            // The root page of your application
            MainPage = new ContentPage() { Content = dataGrid };
            //MainPage = new SfDataPage();
        }

        protected override void OnStart()
        {
            // Handle when your app starts
        }

        protected override void OnSleep()
        {
            // Handle when your app sleeps
        }

        protected override void OnResume()
        {
            // Handle when your app resumes
        }
    }

    public class StyleConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            int _value = (int)value;
            if (_value % 2 == 0)
                return Color.Green;
            return Color.Red;
        }
        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            return value;
        }
    }

    public class GridCellTextViewRendererExt : GridCellTextViewRenderer
    {
        public GridCellTextViewRendererExt()
        {

        }

        public override void OnInitializeDisplayView(DataColumnBase dataColumn, SfLabel view)
        {
            base.OnInitializeDisplayView(dataColumn, view);
            if ((dataColumn.RowData as OrderInfo).IsBold == true)
            {
                view.FontAttributes = FontAttributes.Bold;
            }
            else
                view.FontAttributes = FontAttributes.None;
        }


        public override void OnUpdateDisplayValue(DataColumnBase dataColumn, SfLabel view)
        {
            base.OnUpdateDisplayValue(dataColumn, view);
            if ((dataColumn.RowData as OrderInfo).IsBold == true)
            {
                view.FontAttributes = FontAttributes.Bold;
            }
            else
                view.FontAttributes = FontAttributes.None;
        }
    }
}
